summaryrefslogtreecommitdiffstats
path: root/kmail/folderstorage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/folderstorage.h')
-rw-r--r--kmail/folderstorage.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kmail/folderstorage.h b/kmail/folderstorage.h
index 6bc04df15..550b45e55 100644
--- a/kmail/folderstorage.h
+++ b/kmail/folderstorage.h
@@ -71,7 +71,7 @@ typedef TQValueList<TQ_UINT32> SerNumList;
*
* @section Accounts
* The accounts (of KMail) that are fed into the folder are
- * represented as the children of the folder. They are only stored here
+ * represented as the tqchildren of the folder. They are only stored here
* during runtime to have a reference for which accounts point to a
* specific folder.
*/
@@ -109,10 +109,10 @@ public:
/** Specify, that the folder can't contain mails. */
virtual void setNoContent(bool aNoContent);
- /** Returns, if the folder can't have children */
+ /** Returns, if the folder can't have tqchildren */
virtual bool noChildren() const { return mNoChildren; }
- /** Specify, that the folder can't have children */
+ /** Specify, that the folder can't have tqchildren */
virtual void setNoChildren( bool aNoChildren );
enum ChildrenState {
@@ -120,11 +120,11 @@ public:
HasNoChildren,
ChildrenUnknown
};
- /** Returns if the folder has children,
- * has no children or we don't know */
+ /** Returns if the folder has tqchildren,
+ * has no tqchildren or we don't know */
virtual ChildrenState hasChildren() const { return mHasChildren; }
- /** Specify if the folder has children */
+ /** Specify if the folder has tqchildren */
virtual void setHasChildren( ChildrenState state )
{ mHasChildren = state; }
@@ -245,10 +245,10 @@ public:
* be reflected in the UI. */
virtual bool isCloseToQuota() const;
/** Called by KMMsgBase::seStatus when status of a message has changed
required to keep the number unread messages variable current. */
- virtual void msgStatusChanged( const KMMsgStatus oldStatus,
- const KMMsgStatus newStatus,
+ virtual void msgStatusChanged( const KMMsgtqStatus oldtqStatus,
+ const KMMsgtqStatus newtqStatus,
int idx);
/** Open folder for access.
@@ -364,10 +364,10 @@ public:
void deregisterFromMessageDict();
/** Set the status of the message at index @p idx to @p status. */
- virtual void seStatus(int idx, KMMsgStatus status, bool toggle=false);
+ virtual void setqStatus(int idx, KMMsgtqStatus status, bool toggle=false);
/** Set the status of the message(s) in the TQValueList @p ids to @p status. */
- virtual void seStatus(TQValueList<int>& ids, KMMsgStatus status, bool toggle=false);
+ virtual void setqStatus(TQValueList<int>& ids, KMMsgtqStatus status, bool toggle=false);
void removeJobs();
@@ -245,10 +245,10 @@ public:
* be reflected in the UI. */
virtual bool isCloseToQuota() const;
- /** Called by KMMsgBase::seStatus when status of a message has changed
+ /** Called by KMMsgBase::setqStatus when status of a message has changed
required to keep the number unread messages variable current. */